==> classpath-0.11-rc1.tar.gz: classpath-0.11-rc1/javax/rmi/CORBA/UtilDelegate.java <==
/* UtilDelegate.java -- 
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.rmi.CORBA;

import java.io.InputStream;
import java.io.OutputStream;
import java.rmi.Remote;
import java.rmi.RemoteException;
//import org.omg.CORBA.ORB;
//import org.omg.CORBA.SystemException;
//import org.omg.CORBA.portable.InputStream;
//import org.omg.CORBA.portable.OutputStream;

public interface UtilDelegate
{

  // XXX javax.rmi.ORB -> org.omg.CORBA.ORB
  Object copyObject(Object obj, javax.rmi.ORB orb) throws RemoteException;
  
  // XXX javax.rmi.ORB -> org.omg.CORBA.ORB
  Object[] copyObjects(Object obj[], javax.rmi.ORB orb) throws RemoteException;

  ValueHandler createValueHandler();
    
  String getCodebase(Class clz);
    
  Tie getTie(Remote target);
    
  boolean isLocal(Stub stub) throws RemoteException;

  Class loadClass(String className, String remoteCodebase,
		  ClassLoader loader) throws ClassNotFoundException;

  RemoteException mapSystemException(SystemException ex);

  Object readAny(InputStream in);

  void registerTarget(Tie tie, Remote target);
    
  void unexportObject(Remote target);
    
  RemoteException wrapException(Throwable orig);
    
  void writeAbstractObject(OutputStream out, Object obj);
    
  void writeAny(OutputStream out, Object obj);

  void writeRemoteObject(OutputStream out, Object obj);
}

==> classpath-0.18.tar.gz: classpath-0.18/javax/rmi/CORBA/UtilDelegate.java <==
/* UtilDelegate.java -- 
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.rmi.CORBA;

import java.io.InputStream;
import java.io.OutputStream;
import java.rmi.Remote;
import java.rmi.RemoteException;
//import org.omg.CORBA.ORB;
//import org.omg.CORBA.SystemException;
//import org.omg.CORBA.portable.InputStream;
//import org.omg.CORBA.portable.OutputStream;

public interface UtilDelegate
{

  // XXX javax.rmi.ORB -> org.omg.CORBA.ORB
  Object copyObject(Object obj, javax.rmi.ORB orb) throws RemoteException;
  
  // XXX javax.rmi.ORB -> org.omg.CORBA.ORB
  Object[] copyObjects(Object obj[], javax.rmi.ORB orb) throws RemoteException;

  ValueHandler createValueHandler();
    
  String getCodebase(Class clz);
    
  Tie getTie(Remote target);
    
  boolean isLocal(Stub stub) throws RemoteException;

  Class loadClass(String className, String remoteCodebase,
		  ClassLoader loader) throws ClassNotFoundException;

  RemoteException mapSystemException(SystemException ex);

  Object readAny(InputStream in);

  void registerTarget(Tie tie, Remote target);
    
  void unexportObject(Remote target);
    
  RemoteException wrapException(Throwable orig);
    
  void writeAbstractObject(OutputStream out, Object obj);
    
  void writeAny(OutputStream out, Object obj);

  void writeRemoteObject(OutputStream out, Object obj);
}
